pitchtools.MelodicDiatonicIntervalClass
=======================================

.. autoclass:: abjad.tools.pitchtools.MelodicDiatonicIntervalClass
   :members:
   :undoc-members:
   :show-inheritance:
